@@ -2,79 +2,79 @@ info = {
     "name": "af",
     "date_order": "YMD",
     "january": [
-        "januarie",
-        "jan"
+        "jan",
+        "januarie"
     ],
     "february": [
-        "februarie",
-        "feb"
+        "feb",
+        "februarie"
     ],
     "march": [
         "maart",
         "mrt"
     ],
     "april": [
-        "april",
-        "apr"
+        "apr",
+        "april"
     ],
     "may": [
         "mei"
     ],
     "june": [
-        "junie",
-        "jun"
+        "jun",
+        "junie"
     ],
     "july": [
-        "julie",
-        "jul"
+        "jul",
+        "julie"
     ],
     "august": [
-        "augustus",
-        "aug"
+        "aug",
+        "augustus"
     ],
     "september": [
-        "september",
-        "sep"
+        "sep",
+        "september"
     ],
     "october": [
-        "oktober",
-        "okt"
+        "okt",
+        "oktober"
     ],
     "november": [
-        "november",
-        "nov"
+        "nov",
+        "november"
     ],
     "december": [
-        "desember",
-        "des"
+        "des",
+        "desember"
     ],
     "monday": [
-        "maandag",
-        "ma"
+        "ma",
+        "maandag"
     ],
     "tuesday": [
-        "dinsdag",
-        "di"
+        "di",
+        "dinsdag"
     ],
     "wednesday": [
-        "woensdag",
-        "wo"
+        "wo",
+        "woensdag"
     ],
     "thursday": [
-        "donderdag",
-        "do"
+        "do",
+        "donderdag"
     ],
     "friday": [
-        "vrydag",
-        "vr"
+        "vr",
+        "vrydag"
     ],
     "saturday": [
-        "saterdag",
-        "sa"
+        "sa",
+        "saterdag"
     ],
     "sunday": [
-        "sondag",
-        "so"
+        "so",
+        "sondag"
     ],
     "am": [
         "vm"
@@ -83,8 +83,8 @@ info = {
         "nm"
     ],
     "year": [
-        "jaar",
-        "j"
+        "j",
+        "jaar"
     ],
     "month": [
         "maand",
@@ -95,129 +95,129 @@ info = {
         "wk"
     ],
     "day": [
-        "dag",
-        "d"
+        "d",
+        "dag"
     ],
     "hour": [
-        "uur",
-        "u"
+        "u",
+        "uur"
     ],
     "minute": [
-        "minuut",
+        "m",
         "min",
-        "m"
+        "minuut"
     ],
     "second": [
-        "sekonde",
+        "s",
         "sek",
-        "s"
+        "sekonde"
     ],
     "relative-type": {
-        "1 year ago": [
-            "verlede jaar"
-        ],
-        "0 year ago": [
-            "hierdie jaar"
-        ],
-        "in 1 year": [
-            "volgende jaar"
-        ],
-        "1 month ago": [
-            "verlede maand"
-        ],
-        "0 month ago": [
-            "vandeesmaand"
-        ],
-        "in 1 month": [
-            "volgende maand"
-        ],
-        "1 week ago": [
-            "verlede week"
-        ],
-        "0 week ago": [
-            "vandeesweek"
-        ],
-        "in 1 week": [
-            "volgende week"
-        ],
-        "1 day ago": [
-            "gister"
-        ],
         "0 day ago": [
             "vandag"
         ],
-        "in 1 day": [
-            "môre"
-        ],
         "0 hour ago": [
             "hierdie uur"
         ],
         "0 minute ago": [
             "hierdie minuut"
         ],
+        "0 month ago": [
+            "vandeesmaand"
+        ],
         "0 second ago": [
             "nou"
+        ],
+        "0 week ago": [
+            "vandeesweek"
+        ],
+        "0 year ago": [
+            "hierdie jaar"
+        ],
+        "1 day ago": [
+            "gister"
+        ],
+        "1 month ago": [
+            "verlede maand"
+        ],
+        "1 week ago": [
+            "verlede week"
+        ],
+        "1 year ago": [
+            "verlede jaar"
+        ],
+        "in 1 day": [
+            "môre"
+        ],
+        "in 1 month": [
+            "volgende maand"
+        ],
+        "in 1 week": [
+            "volgende week"
+        ],
+        "in 1 year": [
+            "volgende jaar"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "oor (\\d+) jaar"
+        "\\1 day ago": [
+            "(\\d+) dae gelede",
+            "(\\d+) dag gelede"
         ],
-        "\\1 year ago": [
-            "(\\d+) jaar gelede"
+        "\\1 hour ago": [
+            "(\\d+) uur gelede"
         ],
-        "in \\1 month": [
-            "oor (\\d+) minuut",
-            "oor (\\d+) md"
+        "\\1 minute ago": [
+            "(\\d+) min gelede",
+            "(\\d+) minute gelede",
+            "(\\d+) minuut gelede"
         ],
         "\\1 month ago": [
             "(\\d+) maand gelede",
             "(\\d+) maande gelede",
             "(\\d+) md gelede"
         ],
-        "in \\1 week": [
-            "oor (\\d+) week",
-            "oor (\\d+) weke",
-            "oor (\\d+) w"
+        "\\1 second ago": [
+            "(\\d+) sek gelede",
+            "(\\d+) sekonde gelede",
+            "(\\d+) sekondes gelede"
         ],
         "\\1 week ago": [
+            "(\\d+) w gelede",
             "(\\d+) week gelede",
-            "(\\d+) weke gelede",
-            "(\\d+) w gelede"
+            "(\\d+) weke gelede"
+        ],
+        "\\1 year ago": [
+            "(\\d+) jaar gelede"
         ],
         "in \\1 day": [
-            "oor (\\d+) minuut",
+            "oor (\\d+) dae",
             "oor (\\d+) dag",
-            "oor (\\d+) dae"
-        ],
-        "\\1 day ago": [
-            "(\\d+) dag gelede",
-            "(\\d+) dae gelede"
+            "oor (\\d+) minuut"
         ],
         "in \\1 hour": [
             "oor (\\d+) uur"
         ],
-        "\\1 hour ago": [
-            "(\\d+) uur gelede"
-        ],
         "in \\1 minute": [
-            "oor (\\d+) minuut",
-            "oor (\\d+) min"
+            "oor (\\d+) min",
+            "oor (\\d+) minuut"
         ],
-        "\\1 minute ago": [
-            "(\\d+) minuut gelede",
-            "(\\d+) minute gelede",
-            "(\\d+) min gelede"
+        "in \\1 month": [
+            "oor (\\d+) md",
+            "oor (\\d+) minuut"
         ],
         "in \\1 second": [
+            "oor (\\d+) sek",
             "oor (\\d+) sekonde",
-            "oor (\\d+) sekondes",
-            "oor (\\d+) sek"
+            "oor (\\d+) sekondes"
         ],
-        "\\1 second ago": [
-            "(\\d+) sekonde gelede",
-            "(\\d+) sekondes gelede",
-            "(\\d+) sek gelede"
+        "in \\1 week": [
+            "oor (\\d+) w",
+            "oor (\\d+) week",
+            "oor (\\d+) weke"
+        ],
+        "in \\1 year": [
+            "oor (\\d+) jaar"
         ]
     },
     "locale_specific": {
@@ -227,16 +227,16 @@ info = {
     },
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
